#
# spec file for package reproc
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lib_name libreproc14
%define libpp_name libreproc++14
Name:           reproc
Version:        14.2.4
Release:        3.1
Summary:        A cross-platform (C99/C++11) process library
License:        MIT
URL:            https://github.com/DaanDeMeyer/reproc
Source:         https://github.com/DaanDeMeyer/reproc/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM: https://github.com/DaanDeMeyer/reproc/commit/0b23d88894ccedde04537fa23ea55cb2f8365342.patch
Patch1:         gcc13.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig

%description
reproc (Redirected Process) is a cross-platform C/C++ library that simplifies starting, stopping and communicating with external programs. The main use case is executing command line applications directly from C or C++ code and retrieving their output.

%package -n %{lib_name}
Summary:        Shared library for reproc

%description -n %{lib_name}
reproc (Redirected Process) is a cross-platform C/C++ library that simplifies starting, stopping and communicating with external programs. The main use case is executing command line applications directly from C or C++ code and retrieving their output.

This package holds the shared library for reproc.

%package -n %{libpp_name}
Summary:        Shared library for reproc

%description -n %{libpp_name}
reproc (Redirected Process) is a cross-platform C/C++ library that simplifies starting, stopping and communicating with external programs. The main use case is executing command line applications directly from C or C++ code and retrieving their output.

This package holds the shared library for reproc.

%package devel
Summary:        Development files for reproc
Requires:       %{lib_name} = %{version}
Requires:       %{libpp_name} = %{version}

%description devel
reproc (Redirected Process) is a cross-platform C/C++ library that simplifies starting, stopping and communicating with external programs. The main use case is executing command line applications directly from C or C++ code and retrieving their output.

This package holds the development files for reproc.

%prep
%autosetup -p1

%build
%cmake -DREPROC++:BOOL=ON -DREPROC_TEST=ON
%cmake_build

%install
%cmake_install

%check
%ctest

%post   -n %{lib_name} -p /sbin/ldconfig
%postun -n %{lib_name} -p /sbin/ldconfig
%post   -n %{libpp_name} -p /sbin/ldconfig
%postun -n %{libpp_name} -p /sbin/ldconfig

%files -n %{lib_name}
%license LICENSE
%doc *.md
%{_libdir}/libreproc.so.*

%files -n %{libpp_name}
%license LICENSE
%doc *.md
%{_libdir}/libreproc++.so.*

%files devel
%{_libdir}/libreproc*.so
%{_includedir}/reproc*/
%{_libdir}/cmake/reproc*/
%{_libdir}/pkgconfig/reproc*.pc

%changelog
* Fri May 19 2023 Dirk Müller <dmueller@suse.com>
- gcc13.patch: refresh with the patch that landed upstream
* Tue Apr  4 2023 Dirk Müller <dmueller@suse.com>
- add gcc13.patch to fix build
* Fri Feb 24 2023 Dirk Müller <dmueller@suse.com>
- update to 14.2.4:
  * Bugfix: Fix a memory leak in `reproc_start()` on Windows
  * Bugfix: Fix a memory leak in reproc++ `array` class move
    constructor.
  * Allow passing zero-sized array's to reproc's `input` option
  * Bugfix: Fix sign of EWOULDBLOCK error returned from
    `reproc_read`.
  * Bugfix: Disallow using `fork` option when using `reproc_run`.
  * Bugfix: `reproc_run` now handles forked child processes
    correctly.
  * Bugfix: Sinks of different types can now be passed to
    `reproc::drain`.
  * Bugfix: Processes on Windows returning negative exit codes
    don't cause asserts anymore.
  * Bugfix: Dependency on librt on POSIX (except osx) systems is
    now explicit in CMake.
  * Bugfix: Added missing stdout redirect option to reproc++.
  * Added `reproc_pid`/`process::pid` to get the pid of the
    process
  * Fixed compilation error when including reproc/drain.h in C++
    code
  * Added missing extern "C" block to reproc/run.h
- run tests
* Mon Aug 31 2020 Marcus Rueckert <mrueckert@suse.de>
- update to 14.1.0
* Fri Jul 31 2020 Marcus Rueckert <mrueckert@suse.de>
- initial
